@@ -8,6 +8,7 @@ from __future__ import absolute_import, division, print_function
 
 from collections import OrderedDict, defaultdict
 from locale import getpreferredencoding
+import json
 import os
 from os.path import isdir, isfile, abspath
 import random
@@ -207,7 +208,7 @@ def find_pkg_dir_or_file_in_pkgs_dirs(pkg_dist, m, files_only=False):
 @memoized
 def _read_specs_from_package(pkg_loc, pkg_dist):
     specs = {}
-    if os.path.isdir(pkg_loc):
+    if pkg_loc and os.path.isdir(pkg_loc):
         downstream_file = os.path.join(pkg_loc, 'info/run_exports')
         if os.path.isfile(downstream_file):
             with open(downstream_file) as f:
@@ -216,16 +217,30 @@ def _read_specs_from_package(pkg_loc, pkg_dist):
         elif os.path.isfile(downstream_file + '.yaml'):
             with open(downstream_file + '.yaml') as f:
                 specs = yaml.safe_load(f)
+        elif os.path.isfile(downstream_file + '.json'):
+            with open(downstream_file + '.json') as f:
+                specs = json.load(f)
     if not specs and os.path.isfile(pkg_loc):
+        # switching to json for consistency in conda-build 4
         specs_yaml = utils.package_has_file(pkg_loc, 'info/run_exports.yaml')
-        if specs_yaml:
+        specs_json = utils.package_has_file(pkg_loc, 'info/run_exports.json')
+        if specs_json:
+            specs = json.loads(specs_json)
+        elif specs_yaml:
             specs = yaml.safe_load(specs_yaml)
         else:
             legacy_specs = utils.package_has_file(pkg_loc, 'info/run_exports')
             # exclude packages pinning themselves (makes no sense)
             if legacy_specs:
-                specs = {'weak': [spec.rstrip() for spec in legacy_specs.splitlines()
-                                if not spec.startswith(pkg_dist.rsplit('-', 2)[0])]}
+                weak_specs = set()
+                if hasattr(pkg_dist, "decode"):
+                    pkg_dist = pkg_dist.decode("utf-8")
+                for spec in legacy_specs.splitlines():
+                    if hasattr(spec, "decode"):
+                        spec = spec.decode("utf-8")
+                    if not spec.startswith(pkg_dist.rsplit('-', 2)[0]):
+                        weak_specs.add(spec.rstrip())
+                specs = {'weak': sorted(list(weak_specs))}
     return specs
 
 
@@ -666,6 +681,7 @@ def distribute_variants(metadata, variants, permit_unsatisfiable_variants=False,
 def expand_outputs(metadata_tuples):
     """Obtain all metadata objects for all outputs from recipe.  Useful for outputting paths."""
     expanded_outputs = OrderedDict()
+
     for (_m, download, reparse) in metadata_tuples:
         for (output_dict, m) in _m.get_output_metadata_set(permit_unsatisfiable_variants=False):
             expanded_outputs[m.dist()] = (output_dict, m)
