@@ -6,7 +6,7 @@ from __future__ import absolute_import, division, print_function
 
 import argparse
 from itertools import chain
-from os import makedirs, listdir, sep
+from os import makedirs, listdir, sep, environ
 from os.path import (basename, commonprefix, exists, isabs, isdir,
                      isfile, join, normpath, realpath, relpath)
 import re
@@ -122,7 +122,7 @@ export DISABLE_AUTOBREW=1
 
 # R refuses to build packages that mark themselves as Priority: Recommended
 mv DESCRIPTION DESCRIPTION.old
-grep -v '^Priority: ' DESCRIPTION.old > DESCRIPTION
+grep -va '^Priority: ' DESCRIPTION.old > DESCRIPTION
 $R CMD INSTALL --build .
 
 # Add more build steps here, if they are necessary.
@@ -520,8 +520,18 @@ def get_latest_git_tag(config):
     return tags[-1]
 
 
+def _ssl_no_verify():
+    """Gets whether the SSL_NO_VERIFY environment variable is set to 1 or True.
+
+    This provides a workaround for users in some corporate environments where
+    MITM style proxies make it difficult to fetch data over HTTPS.
+    """
+    return environ.get('SSL_NO_VERIFY', '').strip().lower() in ('1', 'true')
+
+
 def get_session(output_dir, verbose=True):
     session = requests.Session()
+    session.verify = _ssl_no_verify()
     try:
         import cachecontrol
         import cachecontrol.caches
@@ -1095,14 +1105,21 @@ def skeletonize(in_packages, output_dir=".", output_suffix="", add_maintainer=No
                         indent=INDENT, sel=sel_src_and_win))
                     deps.append("{indent}{{{{posix}}}}autoconf        {sel}".format(
                         indent=INDENT, sel=sel_src))
-                    deps.append("{indent}{{{{posix}}}}automake-wrapper{sel}".format(
-                        indent=INDENT, sel=sel_src_and_win))
                     deps.append("{indent}{{{{posix}}}}automake        {sel}".format(
+                        indent=INDENT, sel=sel_src_not_win))
+                    deps.append("{indent}{{{{posix}}}}automake-wrapper{sel}".format(
                         indent=INDENT, sel=sel_src_and_win))
                     deps.append("{indent}{{{{posix}}}}pkg-config".format(indent=INDENT))
                 if need_make:
                     deps.append("{indent}{{{{posix}}}}make            {sel}".format(
                         indent=INDENT, sel=sel_src))
+                    if not need_autotools:
+                        deps.append("{indent}{{{{posix}}}}sed             {sel}".format(
+                            indent=INDENT, sel=sel_src_and_win))
+                    deps.append("{indent}{{{{posix}}}}coreutils       {sel}".format(
+                        indent=INDENT, sel=sel_src_and_win))
+                deps.append("{indent}{{{{posix}}}}zip             {sel}".format(
+                    indent=INDENT, sel=sel_src_and_win))
             elif dep_type == 'run':
                 if need_c or need_cxx or need_f:
                     deps.append("{indent}{{{{native}}}}gcc-libs       {sel}".format(
