@@ -338,7 +338,7 @@ def skeletonize(packages, output_dir=".", version=None, recursive=False,
                 ordered_recipe['build']['noarch'] = 'python'
 
             ordered_recipe['build']['script'] = ('"{{ PYTHON }} -m pip install . --no-deps '
-                                                 '--ignore-installed --no-cache-dir -vvv ' +
+                                                 '--ignore-installed -vvv ' +
                                                  ' '.join(setup_options) + '"')
 
             # Always require python as a dependency.  Pip is because we use pip for
@@ -462,7 +462,7 @@ def add_parser(repos):
         action='store',
         default=default_python,
         help="""Version of Python to use to run setup.py. Default is %(default)s.""",
-        choices=['2.7', '3.4', '3.5'],
+        choices=['2.7', '3.5', '3.6', '3.7'],
     )
 
     pypi.add_argument(
