@@ -42,7 +42,10 @@ def download_to_cache(cache_folder, recipe_path, source_dict):
     if not isdir(cache_folder):
         os.makedirs(cache_folder)
 
-    unhashed_fn = fn = source_dict['fn'] if 'fn' in source_dict else basename(source_dict['url'])
+    source_urls = source_dict['url']
+    if not isinstance(source_urls, list):
+        source_urls = [source_urls]
+    unhashed_fn = fn = source_dict['fn'] if 'fn' in source_dict else basename(source_urls[0])
     hash_added = False
     for hash_type in ('md5', 'sha1', 'sha256'):
         if hash_type in source_dict:
@@ -58,10 +61,8 @@ def download_to_cache(cache_folder, recipe_path, source_dict):
         print('Found source in cache: %s' % fn)
     else:
         print('Downloading source to cache: %s' % fn)
-        if not isinstance(source_dict['url'], list):
-            source_dict['url'] = [source_dict['url']]
 
-        for url in source_dict['url']:
+        for url in source_urls:
             if "://" not in url:
                 if url.startswith('~'):
                     url = expanduser(url)
@@ -195,6 +196,9 @@ def git_mirror_checkout_recursive(git, mirror_dir, checkout_dir, git_url, git_ca
     git_mirror_dir = convert_path_for_cygwin_or_msys2(git, mirror_dir).rstrip('/')
     git_checkout_dir = convert_path_for_cygwin_or_msys2(git, checkout_dir).rstrip('/')
 
+    # Set default here to catch empty dicts
+    git_ref = git_ref or 'HEAD'
+
     mirror_dir = mirror_dir.rstrip('/')
     if not isdir(os.path.dirname(mirror_dir)):
         os.makedirs(os.path.dirname(mirror_dir))
@@ -291,7 +295,7 @@ def git_source(source_dict, git_cache, src_dir, recipe_path=None, verbose=True):
 
     git_url = source_dict['git_url']
     git_depth = int(source_dict.get('git_depth', -1))
-    git_ref = source_dict.get('git_rev', 'HEAD')
+    git_ref = source_dict.get('git_rev') or 'HEAD'
 
     if git_url.startswith('.'):
         # It's a relative path from the conda recipe
