@@ -4,6 +4,7 @@ import base64
 from collections import defaultdict
 import contextlib
 import fnmatch
+import hashlib
 import json
 from locale import getpreferredencoding
 import logging
@@ -1043,7 +1044,8 @@ def find_recipe(path):
 class LoggingContext(object):
     loggers = ['conda', 'binstar', 'install', 'conda.install', 'fetch', 'conda.instructions',
                'fetch.progress', 'print', 'progress', 'dotupdate', 'stdoutlog', 'requests',
-               'conda.core.package_cache', 'conda.plan', 'conda.gateways.disk.delete']
+               'conda.core.package_cache', 'conda.plan', 'conda.gateways.disk.delete',
+               'conda_build', 'conda_build.index']
 
     def __init__(self, level=logging.WARN, handler=None, close=True):
         self.level = level
@@ -1234,6 +1236,7 @@ def apply_pin_expressions(version, min_pin='x.x.x.x.x.x.x', max_pin='x'):
 def filter_files(files_list, prefix, filter_patterns=('(.*[\\\\/])?\.git[\\\\/].*',
                                                       '(.*[\\\\/])?\.git$',
                                                       '(.*)?\.DS_Store.*',
+                                                      '.*\.la$',
                                                       'conda-meta.*')):
     """Remove things like the .git directory from the list of files to be copied"""
     for pattern in filter_patterns:
@@ -1254,6 +1257,7 @@ def filter_info_files(files_list, prefix):
                     'info[\\\\/]hash_input_files',   # legacy, not used anymore
                     'info[\\\\/]hash_input.json',
                     'info[\\\\/]run_exports.yaml',
+                    'info[\\\\/]run_exports.json',
                     'info[\\\\/]git',
                     'info[\\\\/]recipe[\\\\/].*',
                     'info[\\\\/]recipe.tar',
@@ -1452,8 +1456,8 @@ def mmap_mmap(fileno, length, tagname=None, flags=0, prot=mmap_PROT_READ | mmap_
     Hides the differences between mmap.mmap on Windows and Unix.
     Windows has `tagname`.
     Unix does not, but makes up for it with `flags` and `prot`.
-    On both, the defaule value for `access` is determined from how the file
-    was opened so must not be passed in at all to get this default behaviour
+    On both, the default value for `access` is determined from how the file
+    was opened so must not be passed in at all to get this default behaviour.
     '''
     if on_win:
         if access:
@@ -1616,3 +1620,13 @@ def expand_reqs(reqs_entry):
         for sec in reqs_entry:
             reqs_entry[sec] = ensure_list(reqs_entry[sec])
     return reqs_entry
+
+
+def sha256_checksum(filename, buffersize=65536):
+    if not isfile(filename):
+        return None
+    sha256 = hashlib.sha256()
+    with open(filename, 'rb') as f:
+        for block in iter(lambda: f.read(buffersize), b''):
+            sha256.update(block)
+    return sha256.hexdigest()
